==> 0.0.1.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/HyperkycFlutterPlugin.java <==
package co.hyperverge.hyperkyc_flutter;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;

import androidx.annotation.NonNull;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import co.hyperverge.hyperkyc.HyperKyc;
import co.hyperverge.hyperkyc.data.models.HyperKycConfig;
import co.hyperverge.hyperkyc.data.models.HyperKycData;
import co.hyperverge.hyperkyc.data.models.HyperKycResult;
import co.hyperverge.hyperkyc.data.network.BaseResponse;
import co.hyperverge.hyperkyc.data.network.DocCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceMatchApiDetail;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * HyperkycFlutterPlugin
 */
public class HyperkycFlutterPlugin implements FlutterPlugin, ActivityAware, PluginRegistry.ActivityResultListener {
    private static final String TAG = HyperkycFlutterPlugin.class.getCanonicalName();
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel hyperKycChannel;
    protected Context context;
    protected Activity activity;
    private Result pendingResult;
    private final FLHyperKyc flHyperKyc = new FLHyperKyc();
    private final HyperKyc.Contract contract = new HyperKyc.Contract();
    private HyperKycConfig hyperKycConfig;

    private final MethodCallHandler hyperKycMethodCallHandler = (@NonNull MethodCall call, @NonNull Result result) -> {
        pendingResult = result;
        if (call.method.equalsIgnoreCase(FLHyperKycConstants.LAUNCH)) {
            HashMap<String, Object> hyperKycConfigMap = call.argument(FLHyperKycConstants.HYPERKYCCONFIG);
            hyperKycConfig = flHyperKyc.getHyperKycConfigFromMap(hyperKycConfigMap);
            Intent contractIntent = contract.createIntent(activity, hyperKycConfig);
            activity.startActivityForResult(contractIntent, FLHyperKycConstants.REQUEST_CODE_HYPERKYC_LAUNCH);
        } else {
            result.notImplemented();
        }
    };

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        this.context = flutterPluginBinding.getApplicationContext();
        hyperKycChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), FLHyperKycConstants.HYPERKYC_CHANNEL_NAME);
        hyperKycChannel.setMethodCallHandler(hyperKycMethodCallHandler);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        hyperKycChannel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        binding.addActivityResultListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        // Use this function only when necessary
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        // Use this function only when necessary
    }

    @Override
    public void onDetachedFromActivity() {
        // Use this function only when necessary
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        switch (requestCode) {
            case FLHyperKycConstants.REQUEST_CODE_HYPERKYC_LAUNCH:
                handleHyperKycResultData(resultCode, data);
                break;
            default:
                return false;
        }
        return true;
    }

    private void handleHyperKycResultData(int resultCode, Intent data) {
        if (data != null) {
            HyperKycResult hyperKycResult = contract.parseResult(resultCode, data);
            Map<String, Object> resultMap = processHyperKycResult(hyperKycResult);
            pendingResult.success(resultMap);
        }
    }

    private Map<String, Object> processHyperKycResult(HyperKycResult hyperKycResult) {
        Map<String, Object> resultMap = new HashMap<>();
        Map<String, Object> kycData = new HashMap<>();

        HyperKycData hyperKycData = hyperKycResult.getData();
        kycData.put(FLHyperKycConstants.SELECTED_COUNTRY, "");
        kycData.put(FLHyperKycConstants.SELECTED_DOCUMENT, "");
        if (hyperKycData != null) {
            if (hyperKycData.selectedCountry() != null) {
                kycData.put(FLHyperKycConstants.SELECTED_COUNTRY, hyperKycData.selectedCountry());
            }
            if (hyperKycData.selectedDocument() != null) {
                kycData.put(FLHyperKycConstants.SELECTED_DOCUMENT, hyperKycData.selectedDocument());
            }

            List<Map<String, Object>> docDataMapList = new ArrayList<>();
            List<HyperKycData.DocData> docDataList = hyperKycData.docDataList();
            for (HyperKycData.DocData docData : docDataList) {
                Map<String, Object> docDataMap = new HashMap<>();
                docDataMap.put(FLHyperKycConstants.SIDE, FLHyperKycHelper.getStringFromProperty(docData.side()));
                docDataMap.put(FLHyperKycConstants.DOC_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(docData.docImagePath()));
                docDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(docData.action()));

                Map<String, String> responseHeadersMap = docData.responseHeaders();
                docDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                BaseResponse<DocCaptureApiDetail> responseResult = docData.responseResult();
                docDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(responseResult, null, null));

                docDataMapList.add(docDataMap);
            }
            kycData.put(FLHyperKycConstants.DOC_DATA_LIST, docDataMapList);

            HyperKycData.FaceData faceData = hyperKycData.faceData();
            if (faceData != null) {
                Map<String, Object> faceDataMap = new HashMap<>();
                faceDataMap.put(FLHyperKycConstants.CROPPED_FACE_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(faceData.croppedFaceImagePath()));
                faceDataMap.put(FLHyperKycConstants.FULL_FACE_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(faceData.fullFaceImagePath()));
                faceDataMap.put(FLHyperKycConstants.VIDEO_PATH, FLHyperKycHelper.getStringFromProperty(faceData.videoPath()));
                faceDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(faceData.action()));

                Map<String, String> responseHeadersMap = faceData.responseHeaders();
                faceDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                BaseResponse<FaceCaptureApiDetail> responseResult = faceData.responseResult();
                faceDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(null, responseResult, null));

                kycData.put(FLHyperKycConstants.FACE_DATA, faceDataMap);
            } else {
                kycData.put(FLHyperKycConstants.FACE_DATA, new HashMap<>());
            }

            HyperKycData.FaceMatchData faceMatchData = hyperKycData.faceMatchData();
            if (faceMatchData != null) {
                Map<String, Object> faceMatchDataMap = new HashMap<>();
                faceMatchDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(faceMatchData.action()));

                Map<String, String> responseHeadersMap = faceMatchData.responseHeaders();
                faceMatchDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                BaseResponse<FaceMatchApiDetail> responseResult = faceMatchData.responseResult();
                faceMatchDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(null, null, responseResult));

                kycData.put(FLHyperKycConstants.FACE_MATCH_DATA, faceMatchDataMap);
            } else {
                kycData.put(FLHyperKycConstants.FACE_MATCH_DATA, new HashMap<>());
            }

        } else {
            kycData.put(FLHyperKycConstants.DOC_DATA_LIST, new ArrayList<>());
            kycData.put(FLHyperKycConstants.FACE_DATA, new HashMap<>());
            kycData.put(FLHyperKycConstants.FACE_MATCH_DATA, new HashMap<>());
        }

        resultMap.put(FLHyperKycConstants.HYPERKYC_DATA, kycData);
        resultMap.put(FLHyperKycConstants.ERROR_MESSAGE, "");
        if (hyperKycResult instanceof HyperKycResult.Cancelled) {
            // user cancelled
            resultMap.put(FLHyperKycConstants.RESULT, "cancelled");
        } else if (hyperKycResult instanceof HyperKycResult.Failure) {
            // failure
            String reasonForFailure = ((HyperKycResult.Failure) hyperKycResult).getReason();
            resultMap.put(FLHyperKycConstants.ERROR_MESSAGE, reasonForFailure);
            resultMap.put(FLHyperKycConstants.RESULT, "failure");
        } else if (hyperKycResult instanceof HyperKycResult.Success) {
            // success
            resultMap.put(FLHyperKycConstants.RESULT, "success");
        }
        return resultMap;
    }


}

==> 0.0.5.tar.gz: android/src/main/java/co/hyperverge/hyperkyc_flutter/HyperkycFlutterPlugin.java <==
package co.hyperverge.hyperkyc_flutter;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;

import androidx.annotation.NonNull;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import co.hyperverge.hyperkyc.HyperKyc;
import co.hyperverge.hyperkyc.data.models.HyperKycConfig;
import co.hyperverge.hyperkyc.data.models.HyperKycData;
import co.hyperverge.hyperkyc.data.models.HyperKycResult;
import co.hyperverge.hyperkyc.data.network.BaseResponse;
import co.hyperverge.hyperkyc.data.network.DocCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceCaptureApiDetail;
import co.hyperverge.hyperkyc.data.network.FaceMatchApiDetail;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * HyperkycFlutterPlugin
 */
public class HyperkycFlutterPlugin implements FlutterPlugin, ActivityAware, PluginRegistry.ActivityResultListener {
    private static final String TAG = HyperkycFlutterPlugin.class.getCanonicalName();
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel hyperKycChannel;
    protected Context context;
    protected Activity activity;
    private Result pendingResult;
    private final FLHyperKyc flHyperKyc = new FLHyperKyc();
    private final HyperKyc.Contract contract = new HyperKyc.Contract();
    private HyperKycConfig hyperKycConfig;

    private final MethodCallHandler hyperKycMethodCallHandler = (@NonNull MethodCall call, @NonNull Result result) -> {
        pendingResult = result;
        if (call.method.equalsIgnoreCase(FLHyperKycConstants.LAUNCH)) {
            HashMap<String, Object> hyperKycConfigMap = call.argument(FLHyperKycConstants.HYPERKYCCONFIG);
            hyperKycConfig = flHyperKyc.getHyperKycConfigFromMap(hyperKycConfigMap);
            Intent contractIntent = contract.createIntent(activity, hyperKycConfig);
            activity.startActivityForResult(contractIntent, FLHyperKycConstants.REQUEST_CODE_HYPERKYC_LAUNCH);
        } else {
            result.notImplemented();
        }
    };

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        this.context = flutterPluginBinding.getApplicationContext();
        hyperKycChannel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), FLHyperKycConstants.HYPERKYC_CHANNEL_NAME);
        hyperKycChannel.setMethodCallHandler(hyperKycMethodCallHandler);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        hyperKycChannel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
        binding.addActivityResultListener(this);
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        // Use this function only when necessary
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        // Use this function only when necessary
    }

    @Override
    public void onDetachedFromActivity() {
        // Use this function only when necessary
    }

    @Override
    public boolean onActivityResult(int requestCode, int resultCode, Intent data) {
        switch (requestCode) {
            case FLHyperKycConstants.REQUEST_CODE_HYPERKYC_LAUNCH:
                handleHyperKycResultData(resultCode, data);
                break;
            default:
                return false;
        }
        return true;
    }

    private void handleHyperKycResultData(int resultCode, Intent data) {
        if (data != null) {
            HyperKycResult hyperKycResult = contract.parseResult(resultCode, data);
            Map<String, Object> resultMap = processHyperKycResult(hyperKycResult);
            pendingResult.success(resultMap);
        }
    }

    private Map<String, Object> processHyperKycResult(HyperKycResult hyperKycResult) {
        Map<String, Object> resultMap = new HashMap<>();
        Map<String, Object> kycData = new HashMap<>();

        HyperKycData hyperKycData = hyperKycResult.getData();
        kycData.put(FLHyperKycConstants.SELECTED_COUNTRY, "");
        if (hyperKycData != null) {
            if (hyperKycData.selectedCountryId() != null) {
                kycData.put(FLHyperKycConstants.SELECTED_COUNTRY, hyperKycData.selectedCountryId());
            }

            //  Add DocResultList to kycData
            List<Map<String, Object>> docResultMapList = new ArrayList<>();
            List<HyperKycData.DocResult> docResultList = hyperKycData.docResultList();
            for (HyperKycData.DocResult docResult : docResultList) {
                Map<String, Object> docResultMap = new HashMap<>();
                docResultMap.put(FLHyperKycConstants.TAG, FLHyperKycHelper.getStringFromProperty(docResult.tag()));
                docResultMap.put(FLHyperKycConstants.DOCUMENT_ID, FLHyperKycHelper.getStringFromProperty(docResult.documentId()));

                List<Map<String, Object>> docDataMapList = new ArrayList<>();
                List<HyperKycData.DocData> docDataList = docResult.docDataList();
                for (HyperKycData.DocData docData : docDataList) {
                    Map<String, Object> docDataMap = new HashMap<>();
                    docDataMap.put(FLHyperKycConstants.SIDE, FLHyperKycHelper.getStringFromProperty(docData.side()));
                    docDataMap.put(FLHyperKycConstants.DOC_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(docData.docImagePath()));
                    docDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(docData.action()));

                    Map<String, String> responseHeadersMap = docData.responseHeaders();
                    docDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                    BaseResponse<DocCaptureApiDetail> responseResult = docData.responseResult();
                    docDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(responseResult, null, null));

                    docDataMapList.add(docDataMap);
                }
                docResultMap.put(FLHyperKycConstants.DOC_DATA_LIST, docDataMapList);
                docResultMapList.add(docResultMap);
            }
            kycData.put(FLHyperKycConstants.DOC_RESULT_LIST, docResultMapList);

            //  Add FaceData to kycData
            HyperKycData.FaceData faceData = hyperKycData.faceData();
            if (faceData != null) {
                Map<String, Object> faceDataMap = new HashMap<>();
                faceDataMap.put(FLHyperKycConstants.CROPPED_FACE_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(faceData.croppedFaceImagePath()));
                faceDataMap.put(FLHyperKycConstants.FULL_FACE_IMAGE_PATH, FLHyperKycHelper.getStringFromProperty(faceData.fullFaceImagePath()));
                faceDataMap.put(FLHyperKycConstants.VIDEO_PATH, FLHyperKycHelper.getStringFromProperty(faceData.videoPath()));
                faceDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(faceData.action()));

                Map<String, String> responseHeadersMap = faceData.responseHeaders();
                faceDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                BaseResponse<FaceCaptureApiDetail> responseResult = faceData.responseResult();
                faceDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(null, responseResult, null));

                kycData.put(FLHyperKycConstants.FACE_DATA, faceDataMap);
            } else {
                kycData.put(FLHyperKycConstants.FACE_DATA, new HashMap<>());
            }

            //  Add FaceMatchResultList to kycData
            List<Map<String, Object>> faceMatchDataResultMapList = new ArrayList<>();
            List<HyperKycData.FaceMatchResult> faceMatchDataResultList = hyperKycData.faceMatchResultList();
            for (HyperKycData.FaceMatchResult faceMatchResult : faceMatchDataResultList) {
                Map<String, Object> faceMatchResultMap = new HashMap<>();
                faceMatchResultMap.put(FLHyperKycConstants.TAG, FLHyperKycHelper.getStringFromProperty(faceMatchResult.tag()));
                faceMatchResultMap.put(FLHyperKycConstants.DOCUMENT_ID, FLHyperKycHelper.getStringFromProperty(faceMatchResult.documentId()));

                HyperKycData.FaceMatchData faceMatchData = faceMatchResult.faceMatchData();
                Map<String, Object> faceMatchDataMap = new HashMap<>();
                faceMatchDataMap.put(FLHyperKycConstants.ACTION, FLHyperKycHelper.getStringFromProperty(faceMatchData.action()));

                Map<String, String> responseHeadersMap = faceMatchData.responseHeaders();
                faceMatchDataMap.put(FLHyperKycConstants.RESPONSE_HEADERS, FLHyperKycHelper.getResponseHeadersJsonString(responseHeadersMap));

                BaseResponse<FaceMatchApiDetail> responseResult = faceMatchData.responseResult();
                faceMatchDataMap.put(FLHyperKycConstants.RESPONSE_RESULT, FLHyperKycHelper.getResponseResultJsonString(null, null, responseResult));

                faceMatchResultMap.put(FLHyperKycConstants.FACE_MATCH_DATA, faceMatchDataMap);

                faceMatchDataResultMapList.add(faceMatchResultMap);
            }
            kycData.put(FLHyperKycConstants.FACE_MATCH_DATA_RESULT_LIST, faceMatchDataResultMapList);

        } else {
            kycData.put(FLHyperKycConstants.DOC_RESULT_LIST, new ArrayList<>());
            kycData.put(FLHyperKycConstants.FACE_DATA, new HashMap<>());
            kycData.put(FLHyperKycConstants.FACE_MATCH_DATA_RESULT_LIST, new HashMap<>());
        }
        resultMap.put(FLHyperKycConstants.HYPERKYC_DATA, kycData);
        resultMap.put(FLHyperKycConstants.REASON, "");
        if (hyperKycResult.getStatus() == HyperKycResult.Status.CANCELLED) {
            // user cancelled
            resultMap.put(FLHyperKycConstants.STATUS, "cancelled");
        } else if (hyperKycResult.getStatus() == HyperKycResult.Status.FAILURE) {
            // failure
            resultMap.put(FLHyperKycConstants.REASON, hyperKycResult.getReason());
            resultMap.put(FLHyperKycConstants.STATUS, "failure");
        } else if (hyperKycResult.getStatus() == HyperKycResult.Status.SUCCESS) {
            // success
            resultMap.put(FLHyperKycConstants.STATUS, "success");
        }
        return resultMap;
    }
}
